<?php

##################################################################################
#    HOTELDRUID
#    Copyright (C) 2001-2009 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    any later version accepted by Marco Maria Francesco De Santis, which
#    shall act as a proxy as defined in Section 14 of version 3 of the
#    license.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
##################################################################################


if ($pag != "visualizza_contratto.php") echo "
</td><td style=\"width: 5px;\"></td></tr></table>

</td></tr></table>";


if (defined('C_FILE_JS_PERS') and C_FILE_JS_PERS != "" and @is_file(C_FILE_JS_PERS)) echo "
<script type=\"text/javascript\" src=\"".C_FILE_JS_PERS."\">
</script>
";



echo "
</body>
</html>";





?>